@@ -1,3 +1,5 @@
+import os
+
 import asyncpg
 
 
@@ -6,5 +8,5 @@ async def get_connection_pool() -> asyncpg.Pool:
         user='ace',
         password='ace',
         database='ace',
-        host='db',
+        host=os.environ.get('ACE_PG_HOST') or 'pg',
     )
